pub struct LinkTokenCreateRequestAuth {
    pub auth_type_select_enabled: bool,
    pub automated_microdeposits_enabled: bool,
    pub instant_match_enabled: bool,
    pub same_day_microdeposits_enabled: bool,
    pub flow_type: String,
}

Fields

auth_type_select_enabled: bool

Specifies whether Auth Type Select is enabled for the Link session, allowing the end user to choose between linking instantly or manually prior to selecting their financial institution. Note that this can only be true if same_day_microdeposits_enabled is set to true.

automated_microdeposits_enabled: bool

Specifies whether the Link session is enabled for the Automated Micro-deposits flow.

instant_match_enabled: bool

Specifies whether the Link session is enabled for the Instant Match flow.

same_day_microdeposits_enabled: bool

Specifies whether the Link session is enabled for the Same Day Micro-deposits flow.

flow_type: String

This field has been deprecated in favor of auth_type_select_enabled.